aerosoltools.aerosol2d.Aerosol2D.normalize_logdp — aerosoltools 0.1.0 documentation

# aerosoltools.aerosol2d.Aerosol2D.normalize_logdp

Aerosol2D.normalize_logdp(inplace=True)

  Normalize the size distribution data by dlogDp to obtain, e.g., dN/dlogDp.

  ## Parameters

  inplacebool, optional

    If True, modifies current instance in-place. If False, returns a new instance with normalized data.

  ## Returns

  self or aerosolxd

    Instance with normalized size distribution data.

  Parameters:

    inplace (bool)